# Script prenant en entree les outputs de la simu AER-ssp245, et generant les depots
# sur la periode 2015-2020, a etre utilises ensuite par les simus DAMIP.
# Une moyenne glissante sur 3 ans est effectuée, avec pondération [0.25 ; 0.5 ; 0.25].
# Un fichier depots par an est genere au final.
# Th. Lurton IPSL aout 2018

#!/bin/sh

for year in {2015..2020}
do

# Chemins
chemin=/ccc/store/cont003/gencmip6/lurtont/IGCM_OUT/LMDZORINCA/PROD/scenarioAER/AER-ssp245/CHM/Output/MO/
workchemin=/ccc/work/cont003/gencmip6/lurtont/aerosols_from_inca/dep_for_DAMIP/

if [ ! -d ${workchemin} ] ; then mkdir -p ${workchemin} ; fi

# On effectue une moyenne glissante sur trois années, centrée en l'année d'intérêt,
# et de poids [ 1/4 ; 1/2 ; 1/4 ].
prec=$((${year}-1))
suiv=$((${year}+1))

echo '***** Annee '${year}' : Moyenne glissante sur ans '${prec}', '${year}', et '${suiv}'.'

# Adresses generiques des fichiers a traiter
fileprec=${chemin}AER-ssp245_${prec}0101_${prec}1230_1M_inca_dep.nc
fileyear=${chemin}AER-ssp245_${year}0101_${year}1230_1M_inca_dep.nc
filesuiv=${chemin}AER-ssp245_${suiv}0101_${suiv}1230_1M_inca_dep.nc

# Override de l'annee precedente pour 2015 :
if [ ${year} = 2015 ]
then
   echo '*** Comme on est en 2015, je prends 2014 de la simu historical.'
   fileprec=/ccc/store/cont003/gencmip6/lurtont/IGCM_OUT/LMDZORINCA/PROD/historicalAER/LOI6012-histAER-partE/CHM/Output/MO/LOI6012-histAER-partE_20140101_20141230_1M_inca_dep.nc
fi

# Fichiers temporaires avec ponderation (cas generique)
pondprec=${workchemin}dust_ssp245_${prec}0101_${prec}1230_pond.nc
pondyear=${workchemin}dust_ssp245_${year}0101_${year}1230_pond.nc
pondsuiv=${workchemin}dust_ssp245_${suiv}0101_${suiv}1230_pond.nc

# Ponderation des trois anees successives par [ 1/4 ; 1/2 ; 1/4 ]
# et multiplication par un facteur 3 qui disparaitra lors de la moyenne par mois.
# (je procede en deux etapes, l'enchainement cdo ne fonctionne pas)
tmp=${workchemin}temp.nc
cdo selname,seddustci,wetdustci,drydustci ${fileprec} ${tmp}
cdo mulc,.75 ${tmp} ${pondprec}
rm -f ${tmp}
cdo selname,seddustci,wetdustci,drydustci ${fileyear} ${tmp}
cdo mulc,1.5 ${tmp} ${pondyear}
rm -f ${tmp}
cdo selname,seddustci,wetdustci,drydustci ${filesuiv} ${tmp}
cdo mulc,.75 ${tmp} ${pondsuiv}
rm -f ${tmp}

pondtroisans=${workchemin}dep_${prec}0101_${suiv}1230_pond.nc

cdo mergetime ${pondprec} ${pondyear} ${pondsuiv} ${pondtroisans}
rm -f ${pondprec} ${pondyear} ${pondsuiv}

fileout=${workchemin}DUST_INCA_ssp245_1M_${year}.nc

cdo ymonmean ${pondtroisans} ${fileout}
rm -f ${pondtroisans}

# Fix du vecteur-temps
ncks -A -v time_counter,time_centered,time_counter_bounds,time_centered_bounds ${fileyear} ${fileout}

# Fin de boucle sur les années
done
